"""
Custom exceptions relating to the usage of the controller class
"""


class InvalidControllerException(Exception):
    """
    A connection is attempted without auth headers
    """
    # pylint: disable=unnecessary-pass
    pass
